window.globalData = {
    "api": [],
    "docs": [],
    "types": [],
    "configs": {
        "description": "",
        "exclude_inputs": [],
        "logo_url": "",
        "tag_mappings": {},
        "theme": {
            "primary_color": "#FF8C00",
            "secondary_color": "#0D47A1",
            "bg_color": "#f0f4f8",
            "text_color": "#1a202c",
            "highlight_code_bg_color": "#ffe0b2",
            "highlight_code_border_color": "#ff8c00",
            "sidebar_bg_color": "#ffffff",
            "sidebar_text_color": "#1a202c",
            "sidebar_highlight_bg_color": "#0D47A1",
            "sidebar_highlight_text_color": "#ffffff",
            "secondary_sidebar_bg_color": "#e0e7ff",
            "secondary_sidebar_text_color": "#1a202c",
            "secondary_sidebar_highlight_bg_color": "#0D47A1",
            "secondary_sidebar_highlight_text_color": "#ffffff",
            "home_page_welcome_bg_1": "#FF8C00",
            "home_page_welcome_bg_2": "#FFD580",
            "home_page_welcome_text_color": "#ffffff",
            "home_page_card_bg_color": "#ffffff",
            "home_page_card_text_color": "#1a202c",
            "code_bg_color": "#f0f4f8",
            "type_bg_color_1": "#f0f4f8",
            "type_bg_color_2": "#e0e7ff",
            "type_text_color": "#1a202c"
        },
        "title": "Default title",
        "type_mappings": {},
        "verbose": false,
        "version": "0.0.0"
    }
};
